pub enum OutputMessagePayload {
Start,
Done(Option<i32>),
Stdout(LineEnding, Vec<u8>),
Stderr(LineEnding, Vec<u8>),
Error(Error),
}Expand description
The payload of an output message
Variants
Start
Command has started execution
Done(Option<i32>)
Command has exited. Returns the exit status (if available) of the command
Stdout(LineEnding, Vec<u8>)
A single line of standard out formatted as a byte vector. The line ending is included in the enum but not in the byte vector
Stderr(LineEnding, Vec<u8>)
A single line of standard error formatted as a byte vector. The line ending is included in the enum but not in the byte vector
Error(Error)
An error has occurred with the command (usually a malformed command or I/O error). This doesn’t include commands that fail via exit status. That is reported via OutputMessagePayload::Done.