pub type ExitResult = (String, Option<ExitStatus>);Expand description
Exit status tuple. This string is the human-readable command name, the exit status is the exit status code of the process if available
pub type ExitResult = (String, Option<ExitStatus>);Exit status tuple. This string is the human-readable command name, the exit status is the exit status code of the process if available